@@ -5,10 +5,12 @@ from _runonfailure import _RunOnFailureKeywords
 from _element import _ElementKeywords
 from _screenshot import _ScreenshotKeywords
 from _applicationmanagement import _ApplicationManagementKeywords
+from _waiting import _WaitingKeywords
 
 __all__ = ["_LoggingKeywords",
            "_RunOnFailureKeywords",
            "_ElementKeywords",
            "_ScreenshotKeywords",
            "_ApplicationManagementKeywords",
+           "_WaitingKeywords",
           ]
